from distutils.core import setup
setup(
  name = 'courspider',
  packages = ['courspider'],
  version = '0.1',
  description = 'A webscraper API to scrape course data from u of t calenders',
  author = 'Tony Xiao',
  author_email = 'zylphrex@gmail.com',
  url = 'https://github.com/Zylphrex/courspider',
  download_url = 'https://github.com/Zylphrex/courspider/tarball/0.1',
  keywords = ['u of t', 'University', 'Toronto', 'course', 'data'],
  classifiers = [],
)
